@@ -10,8 +10,16 @@ declare_id!("tmeEDp1RgoDtZFtx6qod3HkbQmv9LMe36uqKVvsLTDE");
 pub mod cardinal_time_invalidator {
     use super::*;
 
-    pub fn init(ctx: Context<InitCtx>, expiration: i64) -> ProgramResult {
-        init::handler(ctx, expiration)
+    pub fn init(ctx: Context<InitCtx>, ix: InitIx) -> ProgramResult {
+        init::handler(ctx, ix)
+    }
+
+    pub fn set_expiration(ctx: Context<SetExpirationCtx>) -> ProgramResult {
+        set_expiration::handler(ctx)
+    }
+
+    pub fn extend_expiration(ctx: Context<ExtendExpirationCtx>, payment_amount: u64) -> ProgramResult {
+        extend_expiration::handler(ctx, payment_amount)
     }
 
     pub fn invalidate<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> ProgramResult {
@@ -21,5 +29,4 @@ pub mod cardinal_time_invalidator {
     pub fn close(ctx: Context<CloseCtx>) -> ProgramResult {
         close::handler(ctx)
     }
-
 }
\ No newline at end of file
